# Table of Contents

- [relations](<./relations.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Using Relations](<./Using-Relations.md>)
  - [Overview](<./Using-Relations/Overview.md>)
  - [Explicit Relations](<./Using-Relations/Explicit-Relations.md>)
  - [Parent/Child Relations](<./Using-Relations/ParentChild-Relations.md>)
  - [Requires/Required by Relations](<./Using-Relations/RequiresRequired-by-Relations.md>)
  - [Transitive Relations](<./Using-Relations/Transitive-Relations.md>)
